{*******************************************************}
{                                                       }
{   Demo project author : Gabriel Anass TAOUSSI         }
{                                                       }
{*******************************************************}

unit ImprovableTriSurfaceForm;

interface

uses
  { System }
  System.SysUtils,
  System.Types,
  System.UITypes,
  System.Classes,
  System.Variants,

  { FMX }
  FMX.Types,
  FMX.Controls,
  FMX.Forms,
  FMX.Graphics,
  FMX.Dialogs,

  { Steema }
  FMXTee.Engine,
  FMXTee.Procs,
  FMXTee.Chart,
  FMXTee.Series.TriSurface,
  FMXTee.Series.Surface,
  FMXTee.Tools;

type
  TChartAccess=class(TCustomAxisPanel);

type
  TMyTriSurfaceSeries=class(TTriSurfaceSeries);

type
  TForm1 = class(TForm)
    Timer1: TTimer;
    Chart1: TChart;
    ChartTool1: TRotateTool;
    ChartTool2: TRepaintMonitor;
    procedure FormCreate(Sender: TObject);
    procedure Timer1Timer(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

{$R *.fmx}

procedure TForm1.FormCreate(Sender: TObject);
begin
  with Chart1 do
  begin

    { Walls }
    BackWall.Size                     := 10;
    BackWall.Transparent              := False;
    BottomWall.Size                   := 10;
    LeftWall.Size                     := 10;
    RightWall.Size                    := 10;

    { Legend }
    Legend.Brush.Kind                 := TBrushKind.None;
    Legend.Brush.Gradient.StartColor  := $FF134795;
    Legend.Brush.Gradient.Visible     := False;
    Legend.Visible                    := False;


    { 3D options  }
    Chart3DPercent                    := 100;
    DepthAxis.Visible                 := True;

    View3DOptions.Orthogonal          := False;
    View3DOptions.Perspective         := 100;
    View3DOptions.Zoom                := 65;
    View3DWalls                       := False;

    AllowPanning                      := pmNone;
    Panning.MouseWheel                := pmwNone;
    Zoom.Brush.Kind                   := TBrushKind.None;
    Zoom.MouseButton                  := TMouseButton.mbMiddle;
    Zoom.Pen.Fill.Color               := TAlphaColors.Silver;
    ZoomWheel                         := pmwNormal;
    Align                             := TAlignLayout.Client;
    TabOrder                          := 1;
    TChartAccess(Chart1).ParallelThreads:=TTeeCPU.NumberOfProcessors;

    Size.PlatformDefault              := False;
    ColorPaletteIndex                 := 13;

    Axes.Automatic := true;

    { Chart speed tricks }
    BevelOuter       :=bvNone;
    BufferedDisplay  :=True;
    ClipPoints       :=False;
    Axes.FastCalc    :=True;  // <-- bypass overflow checkings...
    Title.Hide;
    Legend.Hide;
    Walls.Left.Hide;
    Hover.Visible := false;

    var Series1 := TMyTriSurfaceSeries.Create(Chart1);
    { Series speed tricks }
    Series1.Pen.Hide;
    Series1.FastBrush                    := True;
    TMyTriSurfaceSeries(Series1).Reuse3D := true;

    { Other configs }
    Series1.Selected.Hover.Visible := False;
    Series1.Brush.Kind             := TBrushKind.Solid;
    Series1.Transparency := 0;
    Series1.PaletteStyle           := TTeePaletteStyle.psRainbow;
    Series1.UseColorRange          := False;
    Series1.UsePalette             := true;
    Series1.XValues.Name           := 'X';
    Series1.YValues.Name           := 'Y';
    Series1.ZValues.Name           := 'Z';
    Series1.XValues.Order          := loNone;
    Series1.YValues.Order          := loNone;
    Series1.ZValues.Order          := loNone;

    Series1.FillSampleValues(3600); // This is the lowest acceptable sample count
    AddSeries(Series1);

    var ChartTool1 := TRotateTool.create(Chart1);
    ChartTool1.Pen.Color      := TAlphaColors.White;
    ChartTool1.Pen.Fill.Color := TAlphaColors.White;
    Tools.Add(ChartTool1);

  end;


  Showmessage('FMX Default canvas : ' + TCanvasManager.DefaultCanvas.ClassName + sLineBreak
             +'Tee default canvas : ' + TeeDefaultCanvas);
end;


procedure TForm1.Timer1Timer(Sender: TObject);

begin
  Timer1.Enabled:=False;
  With Chart1.View3DOptions do
  begin
    Rotation:=Rotation+1;
    if Rotation>360 then Rotation:=Rotation-360;
  end;
  Timer1.Enabled:=True;
end;
end.
